@@ -6,6 +6,7 @@
 
 {-# LANGUAGE BangPatterns #-}
 {-# LANGUAGE Safe #-}
+{-# LANGUAGE CPP #-}
 
 module Test.QuickCheck.Safe (
     -- * Checking properties
@@ -164,17 +165,12 @@ mapSize f = MkSProperty . scale f . unSProperty . sProperty where
 -- conjoin :: STestable prop => [prop] -> SProperty
 -- counterexample :: STestable prop => String -> prop -> SProperty
 -- cover :: STestable prop => Bool -> Int -> String -> prop -> SProperty
---   (leads to InsufficientCoverage result)
 -- disjoin :: STestable prop => [prop] -> SProperty
 -- expectFailure :: STestable prop => prop -> SProperty
---   (leads to NoExpectedFailure result)
 -- once :: STestable prop => prop -> SProperty
 -- printTestCase :: STestable prop => String -> prop -> SProperty
 -- verbose :: STestable prop => prop -> SProperty
 -- within :: STestable prop => Int -> prop -> SProperty
--- once :: STestable prop => prop -> Property
--- again :: STestable prop => prop -> Property
--- noShrinking :: STestable prop => prop -> Property
 
 -- | Cf. 'Test.QuickCheck.quickCheckWithResult'. Note that in contrast to
 -- QuickCheck's function, this one takes an additional 'QCGen' argument.
@@ -214,6 +210,9 @@ quickCheckWithResult args seed prop = unGen (runTests 0 0 sizes) seed' 0 where
             reason = reason,
             theException = sException res,
             labels = map (\x -> (x, 0)) (sLabels res),
+#if MIN_VERSION_QuickCheck(2,10,0)
+            failingTestCase = sLabels res,
+#endif
             output = "*** Failed! " ++ reason ++
                   " (after " ++ count (pass + 1) "test" ++
                   (if shr > 0 then " and " ++ count shr "shrink" else "") ++
